/*
 Disclaimer: IMPORTANT:  This INVASIVECODE software is supplied to you by INVASIVECODE
 Inc. ("INVASIVECODE") in consideration of your agreement to the following
 terms, and your use, installation, modification or redistribution of
 this INVASIVECODE software constitutes acceptance of these terms.  If you do
 not agree with these terms, please do not use, install, modify or
 redistribute this INVASIVECODE software.
 
 In consideration of your agreement to abide by the following terms, and
 subject to these terms, INVASIVECODE grants you a personal, non-exclusive
 license, under INVASIVECODE's copyrights in this original INVASIVECODE software (the
 "INVASIVECODE Software"), to use, reproduce, modify and redistribute the INVASIVECODE
 Software, with or without modifications, in source and/or binary forms;
 provided that if you redistribute the INVASIVECODE Software in its entirety and
 without modifications, you must retain this notice and the following
 text and disclaimers in all such redistributions of the INVASIVECODE Software.
 Neither the name, trademarks, service marks or logos of INVASIVECODE Inc. may
 be used to endorse or promote products derived from the INVASIVECODE Software
 without specific prior written permission from INVASIVECODE. Except as
 expressly stated in this notice, no other rights or licenses, express or
 implied, are granted by INVASIVECODE herein, including but not limited to any
 patent rights that may be infringed by your derivative works or by other
 works in which the INVASIVECODE Software may be incorporated.
 
 The INVASIVECODE Software is provided by INVASIVECODE on an "AS IS" basis. INVASIVECODE
 MAKES NO WARRANTIES, EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION
 THE IMPLIED WARRANTIES OF NON-INFRINGEMENT, MERCHANTABILITY AND FITNESS
 FOR A PARTICULAR PURPOSE, REGARDING THE INVASIVECODE SOFTWARE OR ITS USE AND
 OPERATION ALONE OR IN COMBINATION WITH YOUR PRODUCTS.
 
 IN NO EVENT SHALL INVASIVECODE BE LIABLE FOR ANY SPECIAL, INDIRECT, INCIDENTAL
 OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 INTERRUPTION) ARISING IN ANY WAY OUT OF THE USE, REPRODUCTION,
 MODIFICATION AND/OR DISTRIBUTION OF THE INVASIVECODE SOFTWARE, HOWEVER CAUSED
 AND WHETHER UNDER THEORY OF CONTRACT, TORT (INCLUDING NEGLIGENCE),
 STRICT LIABILITY OR OTHERWISE, EVEN IF INVASIVECODE HAS BEEN ADVISED OF THE
 POSSIBILITY OF SUCH DAMAGE.
 
 Copyright (C) 2016 INVASIVECODE Inc. All Rights Reserved.*/

import UIKit
import SignaKit

class ViewController: UITableViewController, ISKSignaKitViewControllerDelegate {

    let documents = ["NetServices", "NetworkingOverview", "Streams", "Certificate", "Letter"]
    
    lazy var shareBarButtonItem: UIBarButtonItem = {
       return UIBarButtonItem(barButtonSystemItem: .Action, target: self, action: #selector(ViewController.shareAction(_:)))
    }()
    
    var lastSignedDocument: NSURL?
    
    override func viewDidLoad() {
        super.viewDidLoad()
        // Do any additional setup after loading the view, typically from a nib.
        
        title = NSLocalizedString("Documents", comment: "Navigation Bar Title")
        
        navigationItem.rightBarButtonItem = shareBarButtonItem
        shareBarButtonItem.enabled = false
    }

    func shareAction(sender: AnyObject) {
        guard let documentURL = lastSignedDocument, documentData = NSData(contentsOfURL: documentURL) else { return }
        
        let activityItems = [documentData]
        let viewController = UIActivityViewController(activityItems: activityItems, applicationActivities: nil)
        
        if UIDevice.currentDevice().userInterfaceIdiom == .Pad {
            viewController.modalPresentationStyle = .Popover
            presentViewController(viewController, animated: true, completion: nil)
            
            if let presentationController = viewController.popoverPresentationController {
                presentationController.permittedArrowDirections = .Up
                presentationController.barButtonItem = shareBarButtonItem
            }
        }
        else {
            presentViewController(viewController, animated: true, completion: nil)
        }
    }
    
    // MARK: Table View
    override func numberOfSectionsInTableView(tableView: UITableView) -> Int {
        return 1
    }
    
    override func tableView(tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        return documents.count
    }
    
    override func tableView(tableView: UITableView, cellForRowAtIndexPath indexPath: NSIndexPath) -> UITableViewCell {
        let cell = tableView.dequeueReusableCellWithIdentifier("Cell", forIndexPath: indexPath)
        cell.textLabel?.text = documents[indexPath.row]
        return cell
    }
    
    override func tableView(tableView: UITableView, didSelectRowAtIndexPath indexPath: NSIndexPath) {
        let documentURL = NSBundle.mainBundle().URLForResource(documents[indexPath.row], withExtension: "pdf")
        let viewController = ISKSignaKitViewController(PDFDocument: documentURL)
        viewController.delegate = self
        presentViewController(viewController, animated: true, completion: nil)
    }
    
    // MARK: ICKSignatureViewControllerDelegate
    func signaKitViewController(signaKitViewController: ISKSignaKitViewController, didSignPDFDocumentAtURL documentURL: NSURL?) {
        lastSignedDocument = documentURL
        
        if documentURL != nil {
            shareBarButtonItem.enabled = true
        }
        else {
            shareBarButtonItem.enabled = false
        }
        
        dismissViewControllerAnimated(true, completion: nil)
    }

    func signaKitViewControllerDidCancel(signaKitViewController: ISKSignaKitViewController) {
        dismissViewControllerAnimated(true, completion: nil)
    }
    
}

