/*
 Disclaimer: IMPORTANT:  This INVASIVECODE software is supplied to you by INVASIVECODE
 Inc. ("INVASIVECODE") in consideration of your agreement to the following
 terms, and your use, installation, modification or redistribution of
 this INVASIVECODE software constitutes acceptance of these terms.  If you do
 not agree with these terms, please do not use, install, modify or
 redistribute this INVASIVECODE software.
 
 In consideration of your agreement to abide by the following terms, and
 subject to these terms, INVASIVECODE grants you a personal, non-exclusive
 license, under INVASIVECODE's copyrights in this original INVASIVECODE software (the
 "INVASIVECODE Software"), to use, reproduce, modify and redistribute the INVASIVECODE
 Software, with or without modifications, in source and/or binary forms;
 provided that if you redistribute the INVASIVECODE Software in its entirety and
 without modifications, you must retain this notice and the following
 text and disclaimers in all such redistributions of the INVASIVECODE Software.
 Neither the name, trademarks, service marks or logos of INVASIVECODE Inc. may
 be used to endorse or promote products derived from the INVASIVECODE Software
 without specific prior written permission from INVASIVECODE. Except as
 expressly stated in this notice, no other rights or licenses, express or
 implied, are granted by INVASIVECODE herein, including but not limited to any
 patent rights that may be infringed by your derivative works or by other
 works in which the INVASIVECODE Software may be incorporated.
 
 The INVASIVECODE Software is provided by INVASIVECODE on an "AS IS" basis. INVASIVECODE
 MAKES NO WARRANTIES, EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION
 THE IMPLIED WARRANTIES OF NON-INFRINGEMENT, MERCHANTABILITY AND FITNESS
 FOR A PARTICULAR PURPOSE, REGARDING THE INVASIVECODE SOFTWARE OR ITS USE AND
 OPERATION ALONE OR IN COMBINATION WITH YOUR PRODUCTS.
 
 IN NO EVENT SHALL INVASIVECODE BE LIABLE FOR ANY SPECIAL, INDIRECT, INCIDENTAL
 OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 INTERRUPTION) ARISING IN ANY WAY OUT OF THE USE, REPRODUCTION,
 MODIFICATION AND/OR DISTRIBUTION OF THE INVASIVECODE SOFTWARE, HOWEVER CAUSED
 AND WHETHER UNDER THEORY OF CONTRACT, TORT (INCLUDING NEGLIGENCE),
 STRICT LIABILITY OR OTHERWISE, EVEN IF INVASIVECODE HAS BEEN ADVISED OF THE
 POSSIBILITY OF SUCH DAMAGE.
 
 Copyright (C) 2016 INVASIVECODE Inc. All Rights Reserved.*/

@import UIKit;

@class ISKSignaKitViewController;

/// The delegate of a `ISKSignaKitViewController` object must adopt the `ISKSignaKitViewControllerDelegate` protocol.
///
/// The methods of the protocol allow the delegate to be informed when the user has finished signing the document, or when the user has cancelled the operation.
///
/// - since: 1.0
@protocol ISKSignaKitViewControllerDelegate <UINavigationControllerDelegate>


/// Informs the delegate that the user has cancelled and will not sign the document.
///
/// You are responsible of dismissing the presented `ISKSignaKitViewController` view controller.
///
/// -parameter signaKitViewController: The `ISKSignaKitViewController` object that is informing.
///
/// - since: 1.0
- (void)signaKitViewControllerDidCancel:(nonnull ISKSignaKitViewController *)signaKitViewController;

/// Informs the delegate that the user has finished signing the document and returns the url that points to the new signed document.
///
/// You are responsible of dismissing the presented `ISKSignaKitViewController` view controller.
///
/// -parameter signaKitViewController: The `ISKSignaKitViewController` object that is informing.
/// -parameter documentURL: The URL that points to the new PDF file that has been generated with the signatures added to it. This file is saved in the the caches directory of the app. You are responsible of copying it to another location if you want to save it permanently.
///
/// - since: 1.0
- (void)signaKitViewController:(nonnull ISKSignaKitViewController *)signaKitViewController didSignPDFDocumentAtURL:(nullable NSURL *)documentURL;

@end

/// The `ISKSignaKitViewController` class manages the user intarface for displaying a PDF document, allowing the user to add hand written signatures to it.
///
/// The user can add one or several signatures to each page, and then adjust their size, rotation and position. Pages can be zoomed, to allow for more detailed adjustments of the signature. If a document has several pages, the user can paginate the document, page by page, or select directly a page from the page selector that presents a grid of page thumbnails. There are two ways of exiting the document. If the user cancels, the document is not signed. If the user taps on the Done button, a new PDF document is generated with the signatures added to it. Then the delegate is informed of either operation, and you are responsible of dismmising the view controller
///
/// - since 1.0
@interface ISKSignaKitViewController : UINavigationController

/// The delegate of the `ISKSignaKitViewController`.
///
/// The delegate is notified when the user has finished signing the document (including the url that point to the new signed PDF file), or if the user has cancelled the operation.
///
/// - since: 1.0
@property (weak, nonatomic, nullable) id<ISKSignaKitViewControllerDelegate> delegate;

/// Returns a newly initialized `ISKSignaKitViewController` object. This is the designated initializer.
///
/// This view controller is a subclass of `UINavigationController`. Once you have instantiated it you can present in the same way you present any other navigation controllers. You must pass a valid url that points to a local PDF file.
///
/// -returns: A newly initialized `ISKSignaKitViewController` view controller object.
///
/// -parameter documentURL: The url that points to the local PDF file to be displayed to the user.
///
/// -since: 1.0
- (nonnull instancetype)initWithPDFDocument:(nullable NSURL *)documentURL NS_DESIGNATED_INITIALIZER;

@end
